==> nextcloud-30.0.14.tgz: nextcloud/apps/files_external/l10n/fa.js <==
OC.L10N.register(
    "files_external",
    {
    "Grant access" : " مجوز اعطا دسترسی",
    "Error configuring OAuth2" : "خطا پیکربندی OAuth2",
    "Generate keys" : "تولید کلید",
    "Error generating key pair" : "خطا در تولید جفت کلید",
    "Forbidden to manage local mounts" : "Forbidden to manage local mounts",
    "Storage with ID \"%d\" not found" : "ذخیره سازی با شناسه  \"%d\"  پیدا نشد",
    "Invalid backend or authentication mechanism class" : "کلاس مکانیسم اعتبار پس زمینه یا تأیید اعتبار نامعتبر است",
    "Invalid mount point" : "نقطه نصب نامعتبر است",
    "Objectstore forbidden" : "فروشگاه شی ممنوع است",
    "Invalid storage backend \"%s\"" : "ذخیره ساز backend نامعتبر است  \"%s\" ",
    "Not permitted to use backend \"%s\"" : "استفاده در backend نامعتبر است \"%s\" ",
    "Not permitted to use authentication mechanism \"%s\"" : "استفاده از مکانیسم تأیید اعتبار مجاز نیست  \"%s\" ",
    "Unsatisfied backend parameters" : "پارامترهای ناراضی backend",
    "Unsatisfied authentication mechanism parameters" : "پارامترهای مکانیسم تأیید ناخوشایند",
    "Insufficient data: %s" : "داده ها کافی نیست:  %s ",
    "%s" : " %s ",
    "Access key" : "کلید دسترسی",
    "Secret key" : "کلید مخفی",
    "Builtin" : "ساخته شده",
    "None" : "هیچ‌کدام",
    "OAuth2" : "OAuth2",
    "Client ID" : "شناسه مشتری",
    "Client secret" : "رمز مشتری",
    "OpenStack v2" : "Open Stack v2",
    "Login" : "ورود",
    "Password" : "گذرواژه",
    "Tenant name" : "نام مستاجر",
    "Identity endpoint URL" : "URL پایان نامه هویت",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "دامنه",
    "Rackspace" : "فضای رک",
    "API key" : "کلید API ",
    "Global credentials" : "اعتبار جهانی",
    "Log-in credentials, save in database" : "اعتبارنامه ورود به سیستم، ذخیره در پایگاه داده",
    "Log-in credentials, save in session" : "اعتبارنامه ورود به سیستم، ذخیره در جلسه",
    "RSA public key" : "کلید عمومی RSA",
    "Public key" : "کلید عمومی",
    "RSA private key" : "کلید خصوصی RSA",
    "Private key" : "کلید خصوصی",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Kerberos default realm, defaults to \"WORKGROUP\"",
    "Kerberos ticket Apache mode" : "Kerberos ticket Apache mode",
    "Kerberos ticket" : "تیکت کربروس",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "باکت",
    "Hostname" : "نام میزبان",
    "Port" : "درگاه",
    "Region" : "ناحیه",
    "Storage Class" : "Storage Class",
    "Enable SSL" : "فعال‌سازی SSL",
    "Enable Path Style" : "سبک مسیر را فعال کنید",
    "Legacy (v2) authentication" : "احراز هویت، ارث بری (v2)",
    "WebDAV" : "WebDAV",
    "URL" : "آدرس",
    "Remote subfolder" : "زیر پوشه از راه دور",
    "Secure https://" : "امن https:// ",
    "FTP" : "FTP",
    "Host" : "میزبانی",
    "Secure ftps://" : "امن ftps:// ",
    "Local" : "محلی",
    "Location" : "محل",
    "Nextcloud" : "نکست کلود",
    "SFTP" : "SFTP",
    "Root" : "ریشه",
    "SFTP with secret key login" : "SFTP با ورود به سیستم کلید مخفی",
    "SMB/CIFS" : "SMB/CIFS",
    "Share" : "اشتراک‌گذاری",
    "Show hidden files" : "نمایش فایل‌های مخفی",
    "Verify ACL access when listing files" : "Verify ACL access when listing files",
    "Timeout" : "زمان پایان",
    "SMB/CIFS using OC login" : "SMB/CIFS using OC login",
    "OpenStack Object Storage" : "فضای ذخیره سازی شیء OpenStack",
    "Service name" : "نام سرویس",
    "Request timeout (seconds)" : "درخواست زمان (ثانیه)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "پشتیبانی cURL در PHP فعال یا نصب نشده است. نصب %s امکان پذیر نیست. لطفاً از سرپرست سیستم خود بخواهید که آن را نصب کند.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "پشتیبانی FTP در PHP فعال یا نصب نشده است. نصب %s امکان پذیر نیست. لطفاً از سرپرست سیستم خود بخواهید که آن را نصب کند.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" نصب نشده است. نصب \"%2$s\" امکان پذیر نیست. لطفاً از سرپرست سیستم خود بخواهید که آن را نصب کند.",
    "External storage" : "حافظه خارجی",
    "External storage support" : "پشتیبانی از ذخیره سازی خارجی",
    "Adds basic external storage support" : "پشتیبانی اصلی حافظه خارجی را اضافه می کند",
    "Confirm" : "تأیید",
    "Unable to update this external storage config. {statusMessage}" : "Unable to update this external storage config. {statusMessage}",
    "New configuration successfully saved" : "New configuration successfully saved",
    "Enter missing credentials" : "Enter missing credentials",
    "There was an error with this external storage." : "There was an error with this external storage.",
    "We were unable to check the external storage {basename}" : "We were unable to check the external storage {basename}",
    "Examine this faulty external storage configuration" : "Examine this faulty external storage configuration",
    "Open in Files" : "در فایل باز کنید",
    "There was an error with this external storage. Do you want to review this mount point config in the settings page?" : "There was an error with this external storage. Do you want to review this mount point config in the settings page?",
    "External mount error" : "خظای نصب خارجی",
    "List of external storage." : "List of external storage.",
    "There is no external storage configured. You can configure them in your Personal settings." : "There is no external storage configured. You can configure them in your Personal settings.",
    "There is no external storage configured and you don't have the permission to configure them." : "There is no external storage configured and you don't have the permission to configure them.",
    "No external storage" : "No external storage",
    "Storage type" : "نوع فضای ذخیره‌سازی",
    "Unknown" : "ناشناخته",
    "Scope" : "حوزه",
    "Personal" : "شخصی",
    "System" : "سیستم",
    "(Group)" : "(گروه)",
    "Compatibility with Mac NFD encoding (slow)" : "سازگاری با رمزگذاری Mac NFD (کند)",
    "Enable encryption" : "فعال کردن رمزگذاری",
    "Enable previews" : "فعال سازی پیش نمایش",
    "Enable sharing" : "فعال سازی اشتراک گذاری",
    "Check for changes" : "بررسی برای تغییرات",
    "Never" : "هرگز",
    "Once every direct access" : "دسترسی مستقیم یکبار برای همیشه",
    "Read only" : "فقط خواندنی",
    "Disconnect" : "قطع شدن",
    "Admin defined" : "مدیر تعریف شده",
    "Automatic status checking is disabled due to the large number of configured storages, click to check status" : "Automatic status checking is disabled due to the large number of configured storages, click to check status",
    "Are you sure you want to disconnect this external storage? It will make the storage unavailable in Nextcloud and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself." : "Are you sure you want to disconnect this external storage? It will make the storage unavailable in Nextcloud and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself.",
    "Delete storage?" : "فضای ذخیره سازی را حذف می کنید؟",
    "Click to recheck the configuration" : "برای بررسی مجدد پیکربندی کلیک کنید.",
    "Saved" : "ذخیره شد",
    "Saving …" : "ذخیره کردن …",
    "Save" : "ذخیره",
    "No external storage configured or you don't have the permission to configure them" : "هیچ فضای ذخیره سازی خارجی پیکربندی نشده است یا اجازه پیکربندی آنها را ندارید.",
    "Open documentation" : "مستندات باز",
    "Folder name" : "نام پوشه",
    "Authentication" : "احراز هویت",
    "Configuration" : "پیکربندی",
    "Available for" : "در دسترس برای",
    "Add storage" : "اضافه کردن حافظه",
    "Advanced settings" : "تنظیمات پیشرفته",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "از اعتبار جهانی می توان برای تأیید اعتبار با چندین انبار خارجی که دارای اعتبار یکسانی هستند استفاده کرد.",
    "Error configuring OAuth1" : "خطا پیکربندی OAuth1",
    "Please provide a valid app key and secret." : "لطفا یک کلید و رمز معتبر برای برنامه فرآهم کنید.",
    "OAuth1" : "OAuth1",
    "App key" : "کلید برنامه",
    "App secret" : "کد برنامه"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-31.0.9.tgz: nextcloud/apps/files_external/l10n/fa.js <==
OC.L10N.register(
    "files_external",
    {
    "Grant access" : " مجوز اعطا دسترسی",
    "Error configuring OAuth2" : "خطا پیکربندی OAuth2",
    "Generate keys" : "تولید کلید",
    "Error generating key pair" : "خطا در تولید جفت کلید",
    "Forbidden to manage local mounts" : "Forbidden to manage local mounts",
    "Storage with ID \"%d\" not found" : "ذخیره سازی با شناسه  \"%d\"  پیدا نشد",
    "Invalid backend or authentication mechanism class" : "کلاس مکانیسم اعتبار پس زمینه یا تأیید اعتبار نامعتبر است",
    "Invalid mount point" : "نقطه نصب نامعتبر است",
    "Objectstore forbidden" : "فروشگاه شی ممنوع است",
    "Invalid storage backend \"%s\"" : "ذخیره ساز backend نامعتبر است  \"%s\" ",
    "Not permitted to use backend \"%s\"" : "استفاده در backend نامعتبر است \"%s\" ",
    "Not permitted to use authentication mechanism \"%s\"" : "استفاده از مکانیسم تأیید اعتبار مجاز نیست  \"%s\" ",
    "Unsatisfied backend parameters" : "پارامترهای ناراضی backend",
    "Unsatisfied authentication mechanism parameters" : "پارامترهای مکانیسم تأیید ناخوشایند",
    "Insufficient data: %s" : "داده ها کافی نیست:  %s ",
    "%s" : " %s ",
    "Access key" : "کلید دسترسی",
    "Secret key" : "کلید مخفی",
    "Builtin" : "ساخته شده",
    "None" : "هیچ‌کدام",
    "OAuth2" : "OAuth2",
    "Client ID" : "شناسه مشتری",
    "Client secret" : "رمز مشتری",
    "OpenStack v2" : "Open Stack v2",
    "Login" : "ورود",
    "Password" : "گذرواژه",
    "Tenant name" : "نام مستاجر",
    "Identity endpoint URL" : "URL پایان نامه هویت",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "دامنه",
    "Rackspace" : "فضای رک",
    "API key" : "کلید API ",
    "Global credentials" : "اعتبار جهانی",
    "Log-in credentials, save in database" : "اعتبارنامه ورود به سیستم، ذخیره در پایگاه داده",
    "Log-in credentials, save in session" : "اعتبارنامه ورود به سیستم، ذخیره در جلسه",
    "RSA public key" : "کلید عمومی RSA",
    "Public key" : "کلید عمومی",
    "RSA private key" : "کلید خصوصی RSA",
    "Private key" : "کلید خصوصی",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Kerberos default realm, defaults to \"WORKGROUP\"",
    "Kerberos ticket Apache mode" : "Kerberos ticket Apache mode",
    "Kerberos ticket" : "تیکت کربروس",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "باکت",
    "Hostname" : "نام میزبان",
    "Port" : "درگاه",
    "Region" : "ناحیه",
    "Storage Class" : "Storage Class",
    "Enable SSL" : "فعال‌سازی SSL",
    "Enable Path Style" : "سبک مسیر را فعال کنید",
    "Legacy (v2) authentication" : "احراز هویت، ارث بری (v2)",
    "WebDAV" : "WebDAV",
    "URL" : "آدرس",
    "Remote subfolder" : "زیر پوشه از راه دور",
    "Secure https://" : "امن https:// ",
    "FTP" : "FTP",
    "Host" : "میزبانی",
    "Secure ftps://" : "امن ftps:// ",
    "Local" : "محلی",
    "Location" : "محل",
    "Nextcloud" : "نکست کلود",
    "SFTP" : "SFTP",
    "Root" : "ریشه",
    "SFTP with secret key login" : "SFTP با ورود به سیستم کلید مخفی",
    "SMB/CIFS" : "SMB/CIFS",
    "Share" : "اشتراک‌گذاری",
    "Show hidden files" : "نمایش فایل‌های مخفی",
    "Verify ACL access when listing files" : "Verify ACL access when listing files",
    "Timeout" : "زمان پایان",
    "SMB/CIFS using OC login" : "SMB/CIFS using OC login",
    "OpenStack Object Storage" : "فضای ذخیره سازی شیء OpenStack",
    "Service name" : "نام سرویس",
    "Request timeout (seconds)" : "درخواست زمان (ثانیه)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "پشتیبانی cURL در PHP فعال یا نصب نشده است. نصب %s امکان پذیر نیست. لطفاً از سرپرست سیستم خود بخواهید که آن را نصب کند.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "پشتیبانی FTP در PHP فعال یا نصب نشده است. نصب %s امکان پذیر نیست. لطفاً از سرپرست سیستم خود بخواهید که آن را نصب کند.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" نصب نشده است. نصب \"%2$s\" امکان پذیر نیست. لطفاً از سرپرست سیستم خود بخواهید که آن را نصب کند.",
    "External storage" : "حافظه خارجی",
    "External storage support" : "پشتیبانی از ذخیره سازی خارجی",
    "Adds basic external storage support" : "پشتیبانی اصلی حافظه خارجی را اضافه می کند",
    "Confirm" : "تأیید",
    "Unable to update this external storage config. {statusMessage}" : "Unable to update this external storage config. {statusMessage}",
    "New configuration successfully saved" : "New configuration successfully saved",
    "Enter missing credentials" : "Enter missing credentials",
    "There was an error with this external storage." : "There was an error with this external storage.",
    "We were unable to check the external storage {basename}" : "We were unable to check the external storage {basename}",
    "Examine this faulty external storage configuration" : "Examine this faulty external storage configuration",
    "Open in Files" : "در فایل باز کنید",
    "There was an error with this external storage. Do you want to review this mount point config in the settings page?" : "There was an error with this external storage. Do you want to review this mount point config in the settings page?",
    "External mount error" : "خظای نصب خارجی",
    "List of external storage." : "List of external storage.",
    "There is no external storage configured. You can configure them in your Personal settings." : "There is no external storage configured. You can configure them in your Personal settings.",
    "There is no external storage configured and you don't have the permission to configure them." : "There is no external storage configured and you don't have the permission to configure them.",
    "No external storage" : "No external storage",
    "Storage type" : "نوع فضای ذخیره‌سازی",
    "Unknown" : "ناشناخته",
    "Scope" : "حوزه",
    "Personal" : "شخصی",
    "System" : "سیستم",
    "(Group)" : "(گروه)",
    "Compatibility with Mac NFD encoding (slow)" : "سازگاری با رمزگذاری Mac NFD (کند)",
    "Enable encryption" : "فعال کردن رمزگذاری",
    "Enable previews" : "فعال سازی پیش نمایش",
    "Enable sharing" : "فعال سازی اشتراک گذاری",
    "Check for changes" : "بررسی برای تغییرات",
    "Never" : "هرگز",
    "Once every direct access" : "دسترسی مستقیم یکبار برای همیشه",
    "Read only" : "فقط خواندنی",
    "Disconnect" : "قطع شدن",
    "Admin defined" : "مدیر تعریف شده",
    "Automatic status checking is disabled due to the large number of configured storages, click to check status" : "Automatic status checking is disabled due to the large number of configured storages, click to check status",
    "Delete storage?" : "فضای ذخیره سازی را حذف می کنید؟",
    "Click to recheck the configuration" : "برای بررسی مجدد پیکربندی کلیک کنید.",
    "Saved" : "ذخیره شد",
    "Saving …" : "ذخیره کردن …",
    "Save" : "ذخیره",
    "No external storage configured or you don't have the permission to configure them" : "هیچ فضای ذخیره سازی خارجی پیکربندی نشده است یا اجازه پیکربندی آنها را ندارید.",
    "Open documentation" : "مستندات باز",
    "Folder name" : "نام پوشه",
    "Authentication" : "احراز هویت",
    "Configuration" : "پیکربندی",
    "Available for" : "در دسترس برای",
    "Add storage" : "اضافه کردن حافظه",
    "Advanced settings" : "تنظیمات پیشرفته",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "از اعتبار جهانی می توان برای تأیید اعتبار با چندین انبار خارجی که دارای اعتبار یکسانی هستند استفاده کرد.",
    "Error configuring OAuth1" : "خطا پیکربندی OAuth1",
    "Please provide a valid app key and secret." : "لطفا یک کلید و رمز معتبر برای برنامه فرآهم کنید.",
    "OAuth1" : "OAuth1",
    "App key" : "کلید برنامه",
    "App secret" : "کد برنامه",
    "Are you sure you want to disconnect this external storage? It will make the storage unavailable in Nextcloud and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself." : "Are you sure you want to disconnect this external storage? It will make the storage unavailable in Nextcloud and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself."
},
"nplurals=2; plural=(n > 1);");
